TarSeqQC-package: TarSeqQC: Targeted Sequencing Experiment Quality Control R package
Description
The package models targeted sequencing experiment output using previous
packages. This package includes the new following features:
- Panel model:
- Model customizable feature panels.
- Evaluation of the sequencing run performance at median or
coverage level for each feature.
- Exploration of sequenced features.
- Quality Control of the sequencing run:
- General overview of the run performance.
- Statistical indicators at median or coverage level.
- Xlsx report.
- Customizable scan bam file parameters.
- Customizable pileup build parameters.
- Incorporation of fasta sequence.
- Fast exploration of read profile for particular features or genomic
regions, coloring SNPs occurences.