Learn R Programming

TarSeqQC (version 1.2.0)

addStatSummSheet: Build excel report of the Target Experiment.

Description

addStatSummSheet adds the statistics summary sheet to the workbook that contains the Target Experiment Report.

buildReport builds an excel file containing some statistical results. These are computed to the selected attribute (e.g. 'coverage') along features (e.g. 'amplicon') and genes. If 'imageFile' is null, the graph generated calling the generic plot function will be used.

ggplotColours is a function to know what color is used when ggplot is called.

Usage

addStatSummSheet(object, wb, attributeThres = c(0, 1, 50, 200, 500, Inf), imageFile)
"addStatSummSheet"(object, wb, attributeThres = c(0, 1, 50, 200, 500, Inf), imageFile)
buildReport(object, attributeThres = c(0, 1, 50, 200, 500, Inf), imageFile = NULL, file)
"buildReport"(object, attributeThres = c(0, 1, 50, 200, 500, Inf), imageFile = NULL, file = "Results.xlsx")
ggplotColours(object, n)
"ggplotColours"(object, n)

Arguments

object
TargetExperiment class object.
wb
A workbook object that will contain the report.
attributeThres
Numeric indicating the intervals extreme values.
imageFile
Character indicating the name of the file that contains the plot that could be insert in the report.
file
Character indicating the name of the report.
n
amount of colors.

Value

Workbook object.NULL.colours

See Also

TargetExperiment-class

Examples

Run this code
## Loading the TargetExperiment object
data(ampliPanel,package="TarSeqQC")
# definition of the interval extreme values
attributeThres<-c(0,1,50,200,500, Inf)

## Building the XLSX report
imageFile<-system.file("extdata", "plot.pdf", package="TarSeqQC",
mustWork=TRUE)
buildReport(ampliPanel, attributeThres=attributeThres, imageFile=imageFile,
file="results.xlsx")

Run the code above in your browser using DataLab