Learn R Programming

TarSeqQC (version 1.2.0)

biasExploration: Plot attribute density and boxplot for each bias source quartile.

Description

biasExploration plots density and box-plot of the analyzed attribute for eaach bias source' quartiles. It helps the identification of some bias due to high source values, for example, high gc content. This graphics could plot together using the ggplot2 geom_violin method.

Usage

biasExploration(object, source = c("length", "gc", "pool"), dens = FALSE)
"biasExploration"(object, source = c("length", "gc", "pool"), dens = FALSE)

Arguments

object
TargetExperiment class object.
source
Character 'gc','length', or 'pool' indicating the source bias. In the case of 'gc' and 'length', it will be categorized in four groups according to its quartiles. In the case of 'pool', its groups will be conserved.
dens
Logical indicating if density plot should be added using the geom_violin ggplot2 method.

Value

ggplot2 graphics.

See Also

plot, plotFeatPerform

Examples

Run this code
## Loading the TargetExperiment object
data(ampliPanel, package="TarSeqQC")

# Attribute boxplot and density plot exploration
g<-biasExploration(ampliPanel,source="gc", dens=TRUE)
# x11(type="cairo")
if(interactive()){
g
}

Run the code above in your browser using DataLab