Learn R Programming

TarSeqQC (version 1.2.0)

readFrequencies: Function to explore read frequencies in targeted regions and out targeted regions.

Description

readFrequencies builds a data frame containing the read frequencies falling in targeted regions and out of those, separated by chromosome.

Usage

readFrequencies(object, BPPARAM = bpparam())
"readFrequencies"(object, BPPARAM = bpparam())

Arguments

object
TargetExperiment class object.
BPPARAM
An optional BiocParallelParam instance defining the parallel back-end to be used during evaluation.

Value

data.frame object.

Examples

Run this code
## loading TargetExperiment object
data(ampliPanel, package="TarSeqQC")
## Defining bam file, bed file and fasta file names and paths
setBamFile(ampliPanel)<-system.file("extdata", "mybam.bam", 
    package="TarSeqQC", mustWork=TRUE)
setFastaFile(ampliPanel)<-system.file("extdata", "myfasta.fa", 
    package="TarSeqQC", mustWork=TRUE)

myReadPercentages<-readFrequencies(ampliPanel)

Run the code above in your browser using DataLab